\addlanguage{ancientgreek}{loadhyph-grc.tex}{}{1}{1}
\addlanguage{ibycus}{ibyhyph.tex}{}{2}{2}
\addlanguage{greek}{loadhyph-el-polyton.tex}{}{1}{1}
\addlanguage{polygreek}{loadhyph-el-polyton.tex}{}{1}{1}
\addlanguage{monogreek}{loadhyph-el-monoton.tex}{}{1}{1}
