\ProvidesFile{iso-8859-7.def}
   [2023-03-21 1.9 Greek input encoding file]
%% iso-8859-7 input encoding file by Apostolos Syropoulos
%% with modifications by C.Beccari
%%
%% Copyright 2000 by Aposrtolos Syropoulos All rights reserved
%%
%%  This fil is distributed in the hope that it will be useful,
%%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
%%
%%
%% IMPORTANT NOTICE:
%%
%% This file is subject to the LPPL licence, version 1.3 or any subsequent
%% version. Copy of the LaTeX Project Public Licence is downloadable from
%% any CTAN archive.
%%
\ProvideTextCommandDefault{\textdegree}{\ensuremath{{^\circ}}}
\ProvideTextCommandDefault{\textonehalf}{\ensuremath{\frac12}}
\ProvideTextCommandDefault{\texttwosuperior}{\ensuremath{{^2}}}
\ProvideTextCommandDefault{\textthreesuperior}{\ensuremath{^3}}
\ProvideTextCommandDefault{\textplusminus}{\ensuremath{\pm}}

\DeclareInputText{160}{\nobreakspace}
\DeclareInputText{161}{\textquoteleft}
\DeclareInputText{162}{\textquoteright}
\DeclareInputText{163}{\pounds}
\DeclareInputText{164}{\texteuro}
%\DeclareInputText{165}{} % 0x20AF DRACHMA SIGN
\DeclareInputText{166}{\textbrokenbar}
\DeclareInputText{167}{\textsection}
\DeclareInputText{168}{\textasciidieresis}
\DeclareInputText{169}{\textcopyright}
\DeclareInputText{170}{\ypogegrammeni}
\DeclareInputText{171}{\guillemotleft}
\DeclareInputText{172}{\textlnot}
\DeclareInputText{173}{\-}
%\DeclareInputText{174}{} not defined
\DeclareInputText{175}{\textemdash} % HORIZONTAL BAR 0x2015
\DeclareInputText{176}{\textdegree}
\DeclareInputMath{177}{\textplusminus}
\DeclareInputText{178}{\texttwosuperior}
\DeclareInputText{179}{\textthreesuperior}
\DeclareInputText{180}{\acctonos{}}
\DeclareInputText{181}{\accdialytikatonos{}}
\DeclareInputText{182}{\ensuregreek{\acctonos\textAlpha}}
\DeclareInputText{183}{\textperiodcentered}
\DeclareInputText{184}{\ensuregreek{\acctonos\textEpsilon}}
\DeclareInputText{185}{\ensuregreek{\acctonos\textEta}}
\DeclareInputText{186}{\ensuregreek{\acctonos\textIota}}
\DeclareInputText{187}{\guillemotright}
\DeclareInputText{188}{\ensuregreek{\acctonos\textOmicron}}
\DeclareInputText{189}{\textonehalf}
\DeclareInputText{190}{\ensuregreek{\acctonos\textUpsilon}}
\DeclareInputText{191}{\ensuregreek{\acctonos\textOmega}}
\DeclareInputText{192}{\ensuregreek{\accdialytikatonos\textiota}}
\DeclareInputText{193}{\textAlpha}                  % Α
\DeclareInputText{194}{\textBeta}                   % Β
\DeclareInputText{195}{\textGamma}                  % Γ
\DeclareInputText{196}{\textDelta}                  % Δ
\DeclareInputText{197}{\textEpsilon}                % Ε
\DeclareInputText{198}{\textZeta}                   % Ζ
\DeclareInputText{199}{\textEta}                    % Η
\DeclareInputText{200}{\textTheta}                  % Θ
\DeclareInputText{201}{\textIota}                   % Ι
\DeclareInputText{202}{\textKappa}                  % Κ
\DeclareInputText{203}{\textLambda}                 % Λ
\DeclareInputText{204}{\textMu}                     % Μ
\DeclareInputText{205}{\textNu}                     % Ν
\DeclareInputText{206}{\textXi}                     % Ξ
\DeclareInputText{207}{\textOmicron}                % Ο
\DeclareInputText{208}{\textPi}                     % Π
\DeclareInputText{209}{\textRho}                    % Ρ
%\DeclareInputText{210} not defined
\DeclareInputText{211}{\textSigma}                  % Σ
\DeclareInputText{212}{\textTau}                    % Τ
\DeclareInputText{213}{\textUpsilon}                % Υ
\DeclareInputText{214}{\textPhi}                    % Φ
\DeclareInputText{215}{\textChi}                    % Χ
\DeclareInputText{216}{\textPsi}                    % Ψ
\DeclareInputText{217}{\textOmega}                  % Ω
\DeclareInputText{218}{\ensuregreek{\accdialytika\textIota}}
\DeclareInputText{219}{\ensuregreek{\accdialytika\textUpsilon}}
\DeclareInputText{220}{\ensuregreek{\acctonos\textalpha}}   % ά
\DeclareInputText{221}{\ensuregreek{\acctonos\textepsilon}} % έ
\DeclareInputText{222}{\ensuregreek{\acctonos\texteta}}     % ή
\DeclareInputText{223}{\ensuregreek{\acctonos\textiota}}    % ί
\DeclareInputText{224}{\ensuregreek{\accdialytikatonos\textupsilon}}
\DeclareInputText{225}{\textalpha}                  % α
\DeclareInputText{226}{\textbeta}                   % β
\DeclareInputText{227}{\textgamma}                  % γ
\DeclareInputText{228}{\textdelta}                  % δ
\DeclareInputText{229}{\textepsilon}                % ε
\DeclareInputText{230}{\textzeta}                   % ζ
\DeclareInputText{231}{\texteta}                    % η
\DeclareInputText{232}{\texttheta}                  % θ
\DeclareInputText{233}{\textiota}                   % ι
\DeclareInputText{234}{\textkappa}                  % κ
\DeclareInputText{235}{\textlambda}                 % λ
\DeclareInputText{236}{\textmu}                     % μ
\DeclareInputText{237}{\textnu}                     % ν
\DeclareInputText{238}{\textxi}                     % ξ
\DeclareInputText{239}{\textomicron}                % ο
\DeclareInputText{240}{\textpi}                     % π
\DeclareInputText{241}{\textrho}                    % ρ
\DeclareInputText{242}{\textvarsigma}               % ς
\DeclareInputText{243}{\textsigma}                  % σ
\DeclareInputText{244}{\texttau}                    % τ
\DeclareInputText{245}{\textupsilon}                % υ
\DeclareInputText{246}{\textphi}                    % φ
\DeclareInputText{247}{\textchi}                    % χ
\DeclareInputText{248}{\textpsi}                    % ψ
\DeclareInputText{249}{\textomega}                  % ω
\DeclareInputText{250}{\ensuregreek{\accdialytika\textiota}}
\DeclareInputText{251}{\ensuregreek{\accdialytika\textupsilon}}
\DeclareInputText{252}{\ensuregreek{\acctonos\textomicron}}
\DeclareInputText{253}{\ensuregreek{\acctonos\textupsilon}}
\DeclareInputText{254}{\ensuregreek{\acctonos\textomega}}
%\DeclareInputText{255} not defined
\endinput
